@@ -21,7 +21,7 @@
 #include "httpsubmit.h"
 
 #include <KIO/Job>
-#include <QtCore/QDebug>
+#include <QDebug>
 
 namespace KCDDB
 {
